Module native_methods

Module native_methods 

Structs

NATIVE_METHODS
Format: name, (arity, function) if arity is None, the function is variadic

Type Aliases

NativeMethod
Format: self, args, vm, vm_state, modules, if it returns none, this function doesnt support the type Note: self is not mutable, because its the Pointer to the object, or a “primitive” value